@@ -2,12 +2,13 @@ use crate::key::KEY_ESCAPE;
 use crate::types::{Color, Effect, Key, Note, Rgb8, Speed, Tone, Volume};
 
 // System
-pub const PYXEL_VERSION: &str = "1.5.3";
+pub const PYXEL_VERSION: &str = "1.5.4";
 pub const DEFAULT_TITLE: &str = "Pyxel";
 pub const DEFAULT_SCALE: u32 = 4;
 pub const DEFAULT_FPS: u32 = 30;
 pub const DEFAULT_QUIT_KEY: Key = KEY_ESCAPE;
-pub const DEFAULT_GIF_SEC: u32 = 10;
+pub const DEFAULT_CAPTURE_SCALE: u32 = 2;
+pub const DEFAULT_CAPTURE_SEC: u32 = 10;
 pub const DISPLAY_RATIO: f64 = 0.8;
 pub const BACKGROUND_COLOR: Rgb8 = 0x101018;
 pub const MAX_SKIP_FRAMES: u32 = 9;
@@ -38,7 +39,6 @@ pub const APP_FILE_EXTENSION: &str = ".pyxapp";
 pub const APP_STARTUP_SCRIPT_FILE: &str = ".pyxapp_startup_script";
 pub const RESOURCE_FILE_EXTENSION: &str = ".pyxres";
 pub const RESOURCE_ARCHIVE_DIRNAME: &str = "pyxel_resource/";
-pub const CAPTURE_SCALE: u32 = 2;
 
 // Graphics
 pub const NUM_COLORS: u32 = 16;
@@ -94,10 +94,10 @@ pub const FONT_DATA: [u32; MAX_FONT_CODE as usize - MIN_FONT_CODE as usize + 1]
 // Audio
 pub const CLOCK_RATE: u32 = 1789773; // 1.78 MHz clock rate
 pub const SAMPLE_RATE: u32 = 44100; // 44.1 kHz sample rate
-pub const NUM_SAMPLES: u32 = SAMPLE_RATE / 10;
+pub const NUM_SAMPLES: u32 = SAMPLE_RATE / 30;
 pub const NUM_CLOCKS_PER_TICK: u32 = CLOCK_RATE / 120;
 pub const OSCILLATOR_RESOLUTION: u32 = 32;
-pub const VIBRATO_DEPTH: f64 = 0.025;
+pub const VIBRATO_DEPTH: f64 = 0.015;
 pub const VIBRATO_FREQUENCY: f64 = 6.0;
 pub const NUM_CHANNELS: u32 = 4;
 pub const NUM_SOUNDS: u32 = 64;
