@@ -17,7 +17,7 @@ pub struct System {
     disable_next_frame_skip: bool,
     frame_count: u32,
     quit_key: Key,
-    should_quit: bool,
+    is_paused: bool,
     fps_profiler: Profiler,
     update_profiler: Profiler,
     draw_profiler: Profiler,
@@ -32,7 +32,7 @@ impl System {
             disable_next_frame_skip: true,
             frame_count: 0,
             quit_key,
-            should_quit: false,
+            is_paused: false,
             fps_profiler: Profiler::new(NUM_MEASURE_FRAMES),
             update_profiler: Profiler::new(NUM_MEASURE_FRAMES),
             draw_profiler: Profiler::new(NUM_MEASURE_FRAMES),
@@ -76,18 +76,14 @@ impl Pyxel {
 
     pub fn run<T: PyxelCallback>(&mut self, callback: &mut T) {
         self.system.next_update_ms = self.platform.tick_count() as f64 + self.system.one_frame_ms;
-        if self.update_frame(Some(callback)) {
-            return;
-        }
+        self.update_frame(Some(callback));
         self.draw_frame(Some(callback));
 
         loop {
             let sleep_time = self.wait_for_update_time();
-
             let tick_count = self.platform.tick_count();
             self.system.fps_profiler.end(tick_count);
             self.system.fps_profiler.start(tick_count);
-
             let update_count: u32;
             if self.system.disable_next_frame_skip {
                 update_count = 1;
@@ -101,11 +97,8 @@ impl Pyxel {
                 ) + 1;
                 self.system.next_update_ms += self.system.one_frame_ms * update_count as f64;
             }
-
             for i in 0..update_count {
-                if self.update_frame(Some(callback)) {
-                    return;
-                }
+                self.update_frame(Some(callback));
                 if i < update_count - 1 {
                     self.system.frame_count += 1;
                 }
@@ -116,55 +109,42 @@ impl Pyxel {
 
     pub fn show(&mut self) {
         loop {
-            if self.update_frame(None) {
-                break;
-            }
+            self.update_frame(None);
             self.draw_frame(None);
         }
     }
 
-    pub fn flip(&mut self) -> bool {
+    pub fn flip(&mut self) {
         if self.system.next_update_ms < 0.0 {
             self.system.next_update_ms = self.platform.tick_count() as f64;
         } else {
             self.wait_for_update_time();
         }
         self.system.next_update_ms += self.system.one_frame_ms;
-
         let tick_count = self.platform.tick_count();
         self.system.fps_profiler.end(tick_count);
         self.system.fps_profiler.start(tick_count);
-
-        if self.update_frame(None) {
-            exit(0);
-        }
+        self.update_frame(None);
         self.draw_frame(None);
-        false
     }
 
     pub fn quit(&mut self) {
-        self.system.should_quit = true;
+        exit(0);
     }
 
-    fn update_frame(&mut self, callback: Option<&mut dyn PyxelCallback>) -> bool {
+    fn update_frame(&mut self, callback: Option<&mut dyn PyxelCallback>) {
         self.system
             .update_profiler
             .start(self.platform.tick_count());
-
         self.process_events();
-        self.check_special_input();
-        if self.system.should_quit {
-            return true;
+        if self.system.is_paused {
+            return;
         }
+        self.check_special_input();
         if let Some(callback) = callback {
             callback.update(self);
         }
-        if self.system.should_quit {
-            return true;
-        }
-
         self.system.update_profiler.end(self.platform.tick_count());
-        false
     }
 
     fn process_events(&mut self) {
@@ -172,11 +152,22 @@ impl Pyxel {
         while let Some(event) = self.platform.poll_event() {
             match event {
                 Event::Quit => {
-                    self.system.should_quit = true;
+                    self.quit();
+                }
+                Event::FocusGained | Event::Maximized => {
+                    self.system.is_paused = false;
+                    self.system.disable_next_frame_skip = true;
+                    self.platform.resume_audio();
+                }
+                Event::FocusLost | Event::Minimized => {
+                    self.system.is_paused = true;
+                    self.platform.pause_audio();
                 }
                 _ => {
-                    self.input
-                        .process_input_event(event, self.system.frame_count);
+                    if !self.system.is_paused {
+                        self.input
+                            .process_input_event(event, self.system.frame_count);
+                    }
                 }
             }
         }
@@ -191,17 +182,17 @@ impl Pyxel {
                 self.system.enable_perf_monitor = !self.system.enable_perf_monitor;
             }
             if self.btnp(KEY_1, None, None) {
-                self.screenshot();
+                self.screenshot(None);
             }
             if self.btnp(KEY_2, None, None) {
                 self.reset_capture();
             }
             if self.btnp(KEY_3, None, None) {
-                self.screencast();
+                self.screencast(None);
             }
         }
         if self.btnp(self.system.quit_key, None, None) {
-            self.system.should_quit = true;
+            self.quit();
         }
     }
 
@@ -216,8 +207,10 @@ impl Pyxel {
     }
 
     fn draw_frame(&mut self, callback: Option<&mut dyn PyxelCallback>) {
+        if self.system.is_paused {
+            return;
+        }
         self.system.draw_profiler.start(self.platform.tick_count());
-
         if let Some(callback) = callback {
             callback.draw(self);
         }
@@ -228,7 +221,6 @@ impl Pyxel {
         self.resource
             .capture_screen(self.screen.clone(), &self.colors, self.system.frame_count);
         self.system.frame_count += 1;
-
         self.system.draw_profiler.end(self.platform.tick_count());
     }
 
@@ -279,7 +271,6 @@ impl Pyxel {
         if x <= -width || x >= self.width() as i32 || y <= -height || y >= self.height() as i32 {
             return;
         }
-
         let mut screen = self.screen.lock();
         let clip_rect = screen.canvas.clip_rect;
         let camera_x = screen.canvas.camera_x;
@@ -288,7 +279,6 @@ impl Pyxel {
         screen.clip0();
         screen.camera0();
         screen.pal0();
-
         screen.blt(
             x as f64,
             y as f64,
@@ -299,7 +289,6 @@ impl Pyxel {
             height as f64,
             Some(0),
         );
-
         screen.canvas.clip_rect = clip_rect;
         screen.canvas.camera_x = camera_x;
         screen.canvas.camera_y = camera_y;
